pub struct BlockEngineValidatorClient<T> { /* private fields */ }Expand description
/ Validators can connect to Block Engines to receive packets and bundles.
Implementations
Sourceimpl<T> BlockEngineValidatorClient<T>where
T: GrpcService<BoxBody>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
impl<T> BlockEngineValidatorClient<T>where
T: GrpcService<BoxBody>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
pub fn new(inner: T) -> Self
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> BlockEngineValidatorClient<InterceptedService<T, F>>where
F: Interceptor,
T::ResponseBody: Default,
T: Service<Request<BoxBody>, Response = Response<<T as GrpcService<BoxBody>>::ResponseBody>>,
<T as Service<Request<BoxBody>>>::Error: Into<StdError> + Send + Sync,
Sourcepub fn send_gzip(self) -> Self
pub fn send_gzip(self) -> Self
Compress requests with gzip.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_gzip(self) -> Self
pub fn accept_gzip(self) -> Self
Enable decompressing responses with gzip.
Sourcepub async fn subscribe_packets(
&mut self,
request: impl IntoRequest<SubscribePacketsRequest>,
) -> Result<Response<Streaming<SubscribePacketsResponse>>, Status>
pub async fn subscribe_packets( &mut self, request: impl IntoRequest<SubscribePacketsRequest>, ) -> Result<Response<Streaming<SubscribePacketsResponse>>, Status>
/ Validators can subscribe to the block engine to receive a stream of packets
Sourcepub async fn subscribe_bundles(
&mut self,
request: impl IntoRequest<SubscribeBundlesRequest>,
) -> Result<Response<Streaming<SubscribeBundlesResponse>>, Status>
pub async fn subscribe_bundles( &mut self, request: impl IntoRequest<SubscribeBundlesRequest>, ) -> Result<Response<Streaming<SubscribeBundlesResponse>>, Status>
/ Validators can subscribe to the block engine to receive a stream of simulated and profitable bundles